##

- Opret bruger
- Log ind
- Hjælp
- Sælg din bil

# Opret ny bruger

eller

Vi gemmer kun dine grundlæggende Facebookoplysninger. Vi kender og gemmer ikke din adgangskode.

Jeg accepterer Bil Markedets brugervilkår og fortrolighedspolitik for Bilbasen.dk.

- Du mangler at godkende brugervilkår og fortrolighedspolitik

Fortrolighedspolitikken indeholder samtykke fra dig til at modtage (a) E-mails med tilbud vedrørende dine annoncer på BilBasen, (b) E-mails om nye eller forbedrede funktioner, muligheder for annoncering, oplysning, tilbud eller kampagner vedrørende annoncering og/eller annoncer på BilBasen samt vedrørende koncernforbundne selskaber, herunder dba.dk og ebay.com, (c) E-mails fra BilBasens fordelsklub med markedsføring fra vores særlige samarbejdspartnere vedrørende eksempelvis køb og salg af køretøjer, service og vedligehold, reservedele og tilbehør, finansiering, forsikring, rejser, ejendomshandel og meget mere.

Fortrolighedspolitikken indeholder et samtykke fra dig til Bil Markedets behandling af personoplysninger, herunder brug til markedsføring i overensstemmelse med dit samtykke.

Du kan begrænse dit samtykke her.

Jeg accepterer Bil Markedets Brugervilkår og Fortrolighedspolitik og ønsker at modtage:

E-mails med tilbud vedrørende dine annoncer på BilBasen (fx tilbud specifikt relateret til dine annoncer på BilBasen, herunder for produkter/services, der kan forbedre dine muligheder for hurtigt salg)

E-mails om nye eller forbedrede funktioner, muligheder for annoncering, oplysning, tilbud eller kampagner vedrørende annoncering og/eller annoncer på BilBasen samt vedrørende koncernforbundne selskaber, herunder dba.dk og ebay.com (fx tilbud, herunder rabatter på annoncering, nyhedsbreve, information mv. vedrørende BilBasen og koncernforbundne selskaber så som DBA og eBay)

E-mails fra BilBasens fordelsklub med markedsføring fra vores særlige samarbejdspartnere vedrørende eksempelvis køb og salg af køretøjer, service og vedligehold, reservedele og tilbehør, finansiering, forsikring, rejser, ejendomshandel og meget mere (fx tilbud inden for forskellige kategorier af varer/services, der udsendes af BilBasen på vegne af en skiftende kreds af samarbejdsparterne)

Allerede bruger på BilBasen? Log ind her